@@ -146,7 +146,7 @@ if(!is.null(X))
 }else
 {}
 
-    if(is.null(prior.tau2)) prior.tau2 <- c(0.001, 0.001)
+    if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)
      if(length(prior.tau2)!=2) stop("the prior value for tau2 is the wrong length.", call.=FALSE)    
     if(!is.numeric(prior.tau2)) stop("the prior value for tau2 is not numeric.", call.=FALSE)    
     if(sum(is.na(prior.tau2))!=0) stop("the prior value for tau2 has missing values.", call.=FALSE)    
@@ -263,7 +263,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * n
     if(sum(is.na(W))>0) stop("W has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(W)) stop("W has non-numeric values.", call.=FALSE)
     if(min(W)<0) stop("W has negative elements.", call.=FALSE)
-    if(sum(W!=t(W))>0) stop("W is not symmetric.", call.=FALSE)
+    if(!is.symmetric.matrix(W)) stop("W is not symmetric.", call.=FALSE)
     if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
 
 ## Create the triplet object
@@ -302,7 +302,7 @@ temp <- 1
 ## Start timer
      if(verbose)
      {
-     cat("Collecting", n.sample, "samples\n", sep = " ")
+         cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
      progressBar <- txtProgressBar(style = 3)
      percentage.points<-round((1:100/100)*n.sample)
      }else
