@@ -136,8 +136,8 @@ alpha <- runif(n=q, min=rep(0,q), max=(alpha.max/(2+q)))
 ## Put in default priors
     if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
     if(is.null(prior.var.beta)) prior.var.beta <- rep(1000, p)
-    if(is.null(prior.tau2)) prior.tau2 <- c(0.001, 0.001)
-    if(is.null(prior.nu2)) prior.nu2 <- c(0.001, 0.001)
+    if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)
+    if(is.null(prior.nu2)) prior.nu2 <- c(1, 0.01)
 
     
 ## Checks    
@@ -204,7 +204,7 @@ nu2.posterior.shape <- prior.nu2[1] + 0.5*(n-n.miss)
     if(sum(is.na(W))>0) stop("W has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(W)) stop("W has non-numeric values.", call.=FALSE)
     if(!sum(names(table(W))==c(0,1))==2) stop("W has non-binary (zero and one) values.", call.=FALSE)
-    if(sum(W!=t(W))>0) stop("W is not symmetric.", call.=FALSE)
+    if(!is.symmetric.matrix(W)) stop("W is not symmetric.", call.=FALSE)
     if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
 
 
@@ -298,7 +298,7 @@ data.precision.beta <- t(X.short) %*% X.short
 ## Start timer
      if(verbose)
      {
-     cat("Collecting", n.sample, "samples\n", sep = " ")
+         cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
      progressBar <- txtProgressBar(style = 3)
      percentage.points<-round((1:100/100)*n.sample)
      }else
