@@ -92,7 +92,10 @@ gaussian.lerouxCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1,
     if(!is.numeric(offset)) stop("the offset variable has non-numeric values.", call.=FALSE)
     offset.short <- offset[which.miss==1]
     
-    
+    ## Check for errors on rho and fix.rho
+    if(!is.logical(fix.rho)) stop("fix.rho is not logical.", call.=FALSE)   
+    if(fix.rho & is.null(rho)) stop("rho is fixed but an initial value was not set.", call.=FALSE)   
+    if(fix.rho & !is.numeric(rho) ) stop("rho is fixed but is not numeric.", call.=FALSE)  
     
     #### Initial parameter values
     mod.glm <- lm(Y~X.standardised-1, offset=offset)
@@ -106,15 +109,16 @@ gaussian.lerouxCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1,
     tau2 <- var(phi) / 10
     nu2 <- tau2
     if(!fix.rho) rho <- runif(1)
-    
+    if(rho<0 ) stop("rho is outside the range [0, 1].", call.=FALSE)  
+    if(rho>1 ) stop("rho is outside the range [0, 1].", call.=FALSE)   
     
     
     #### Priors
     ## Put in default priors
     if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
     if(is.null(prior.var.beta)) prior.var.beta <- rep(1000, p)
-    if(is.null(prior.tau2)) prior.tau2 <- c(0.001, 0.001)
-    if(is.null(prior.nu2)) prior.nu2 <- c(0.001, 0.001)
+    if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)
+    if(is.null(prior.nu2)) prior.nu2 <- c(1, 0.01)
     
     
     ## Checks    
@@ -153,14 +157,6 @@ gaussian.lerouxCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1,
     if(thin!=round(thin)) stop("thin is not an integer.", call.=FALSE) 
     
 
-    ## Check for errors on rho and fix.rho
-    if(!is.logical(fix.rho)) stop("fix.rho is not logical.", call.=FALSE)   
-    if(fix.rho & is.null(rho)) stop("rho is fixed but an initial value was not set.", call.=FALSE)   
-    if(fix.rho & !is.numeric(rho) ) stop("rho is not numeric.", call.=FALSE)  
-    if(rho<0 ) stop("rho is outside the range [0, 1].", call.=FALSE)  
-    if(rho>1 ) stop("rho is outside the range [0, 1].", call.=FALSE)      
-
-    
     ## Matrices to store samples
     n.keep <- floor((n.sample - burnin)/thin)
     samples.beta <- array(NA, c(n.keep, p))
@@ -189,8 +185,21 @@ gaussian.lerouxCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1,
     if(sum(is.na(W))>0) stop("W has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(W)) stop("W has non-numeric values.", call.=FALSE)
     if(min(W)<0) stop("W has negative elements.", call.=FALSE)
-    if(sum(W!=t(W))>0) stop("W is not symmetric.", call.=FALSE)
-    if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
+    if(!is.symmetric.matrix(W)) stop("W is not symmetric.", call.=FALSE)
+    
+    if(fix.rho & rho==0)
+    {
+        ## Set up a dummy W matrix to use in the code as it will not affect the results
+        W <- array(0, c(n,n))
+        for(r in 2:n)
+        {
+            W[(r-1), r] <- 1   
+            W[r, (r-1)] <- 1
+        }
+    }else
+    {
+        if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
+    }
     
     
     ## Create the triplet object
@@ -222,10 +231,14 @@ gaussian.lerouxCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1,
     
     
     ## Create the determinant     
-    Wstar <- diag(apply(W,1,sum)) - W
-    Wstar.eigen <- eigen(Wstar)
-    Wstar.val <- Wstar.eigen$values
-    if(!fix.rho) det.Q <-  0.5 * sum(log((rho * Wstar.val + (1-rho))))    
+    if(!fix.rho)
+    {
+        Wstar <- diag(apply(W,1,sum)) - W
+        Wstar.eigen <- eigen(Wstar)
+        Wstar.val <- Wstar.eigen$values
+        det.Q <- 0.5 * sum(log((rho * Wstar.val + (1-rho))))    
+    }else
+    {}   
     
     
     ## Check for islands
@@ -256,7 +269,7 @@ gaussian.lerouxCAR <- function(formula, data=NULL, W, burnin, n.sample, thin=1,
     ## Start timer
     if(verbose)
     {
-        cat("Collecting", n.sample, "samples\n", sep = " ")
+        cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
         progressBar <- txtProgressBar(style = 3)
         percentage.points<-round((1:100/100)*n.sample)
     }else
