@@ -28,12 +28,12 @@ print.carbayes <- function(x,...)
         cat("############\n")
         cat("Posterior quantities and DIC\n\n")
         print(x$summary.results)
-        cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", x$modelfit[3],"\n")
+        cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", x$modelfit[5],"\n")
 
         cat("\nThe number of stepchanges identified in the random effect surface\n")
         temp <- x$localised.structure[[1]][!is.na(x$localised.structure[[1]])]
         tab <- array(NA, c(1,2))
-        tab[1, ] <- c(sum(temp), length(temp)- sum(temp))
+        tab[1, ] <- c(sum(temp)/2, length(temp)/2- sum(temp)/2)
         colnames(tab) <- c("no stepchange", "stepchange")
         print(tab)
     }else if(class(x$localised.structure)=="numeric")
@@ -55,7 +55,7 @@ print.carbayes <- function(x,...)
         cat("############\n")
         cat("Posterior quantities and DIC\n\n")
         print(x$summary.results)
-        cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", x$modelfit[3],"\n")
+        cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", x$modelfit[5],"\n")
         cat("\nNumber of clusters with the number of data points in each one\n")
         print(table(paste("group", x$localised.structure, sep="")))
         
@@ -78,7 +78,7 @@ print.carbayes <- function(x,...)
         cat("############\n")
         cat("Posterior quantities and DIC\n\n")
         print(x$summary.results)
-        cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", x$modelfit[3],"\n")
+        cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", x$modelfit[5],"\n")
      }
         
 return(invisible(x))        
